==> 3DPeopleCounter_1_02_0%285%29.tar.gz: package/apps/gui/static/js/counter/settings.js <==
/*global $, params*/
"use strict";
$(function() {
    var restrict = params.counter.zone_restrictions;
    $("#schedule_sliders").schedule();
    if ( params.counter.use_zone ) {
        $("#counting_zone").countingZone({
            canvas: "video_canvas",
            width: params.ui.stream_width,
            height: params.ui.stream_height,
            restriction: {
                left: restrict.horizontal_margin,
                right: 1 - restrict.horizontal_margin,
                top: restrict.vertical_margin,
                bottom: 1 - restrict.vertical_margin,
                max_height: restrict.max_height,
                min_height: restrict.min_height,
                min_width: restrict.min_width,
                max_width: restrict.max_width,
                fix_height: restrict.fix_height
            }
        });
    } else {
        $("#counting_zone_notification").hide().siblings(".fieldHelp").hide();
    }
    /* As the sliders for couting zone is built dynamically this must also be done here. */
    $(".ui-slider-handle").on("focus", function () {
        $(this).parent().parent(".ctrlHolder").addClass("focused");
    }).blur(function () {
        $(this).parent().parent(".ctrlHolder").removeClass("focused");
    });

    $("#anonymize").click(function(e) {
        e.preventDefault();
        if ( !confirm("This will put the camera in anonymized mode, all video streams will be disabled. Do you want to continue?") ) {
            return;
        }
        $('#overlay').show();
        $.post("/stereo/anonymize/anonymize", {}, function(data) {
            if (data && data['status'] == 'CM_OK') {
                $.waitForAnon(function() {
                    $('#overlay').hide();
                    alert("Successfully anonymized camera.");
                }, true);
            } else {
                $('#overlay').hide();
                if ( data && data.status ) {
                    alert("Could not anonymize: " + data.status);
                } else {
                    alert("Could not anonymize.");
                }
            }
        }).fail(function() {
            $('#overlay').hide();
            alert("Could not anonymize.");
        });
    });

    $("#anonymize-reset").click(function(e) {
        e.preventDefault();
        if ( !confirm("This will disable anonymized mode and restore the video streams. Do you want to continue?") ) {
            return;
        }
        $('#overlay').show();
        $.post("/stereo/anonymize/reset", {}, function(data) {
            if (data && data['status'] == 'CM_OK') {
                $.waitForAnon(function() {
                    $('#overlay').hide();
                    alert("Anonymization resetted.");
                }, false);
            } else {
                $('#overlay').hide();
                if ( data && data.status ) {
                    alert("Could not reset anonymization: " + data.status);
                } else {
                    alert("Could not reset anonymization.");
                }
            }
        }).fail(function() {
            $('#overlay').hide();
            alert("Could not reset anonymization.");
        });
    });
});

==> 3DPeopleCounter_1_04_0%285%29.tar.gz: package/apps/gui/static/js/counter/settings.js <==
/*global $, params*/
"use strict";
$(function() {
    var restrict = params.counter.zone_restrictions;
    $("#schedule_sliders").schedule();
    if ( params.counter.use_zone ) {
        $("#counting_zone").countingZone({
            canvas: "video_canvas",
            width: params.ui.stream_width,
            height: params.ui.stream_height,
            restriction: {
                left: restrict.horizontal_margin,
                right: 1 - restrict.horizontal_margin,
                top: restrict.vertical_margin,
                bottom: 1 - restrict.vertical_margin,
                max_height: restrict.max_height,
                min_height: restrict.min_height,
                min_width: restrict.min_width,
                max_width: restrict.max_width,
                fix_height: restrict.fix_height
            }
        });
    } else {
        $("#counting_zone_notification").hide().siblings(".fieldHelp").hide();
    }
    /* As the sliders for couting zone is built dynamically this must also be done here. */
    $(".ui-slider-handle").on("focus", function () {
        $(this).parent().parent(".ctrlHolder").addClass("focused");
    }).blur(function () {
        $(this).parent().parent(".ctrlHolder").removeClass("focused");
    });

    $("#anonymize").click(function(e) {
        e.preventDefault();
        if ( !confirm("This will put the camera in anonymized mode, all video streams will be disabled. Do you want to continue?") ) {
            return;
        }
        $('#overlay').show();
        $.post("/stereo/anonymize/anonymize", {}, function(data) {
            if (data && data['status'] == 'CM_OK') {
                $.waitForAnon(function() {
                    $('#overlay').hide();
                    alert("Successfully anonymized camera.");
                }, true);
            } else {
                $('#overlay').hide();
                if ( data && data.status ) {
                    alert("Could not anonymize: " + data.status);
                } else {
                    alert("Could not anonymize.");
                }
            }
        }).fail(function() {
            $('#overlay').hide();
            alert("Could not anonymize.");
        });
    });

    $("#anonymize-reset").click(function(e) {
        e.preventDefault();
        if ( !confirm("This will disable anonymized mode and restore the video streams. Do you want to continue?") ) {
            return;
        }
        $('#overlay').show();
        $.post("/stereo/anonymize/reset", {}, function(data) {
            if (data && data['status'] == 'CM_OK') {
                $.waitForAnon(function() {
                    $('#overlay').hide();
                    alert("Anonymization reset.");
                }, false);
            } else {
                $('#overlay').hide();
                if ( data && data.status ) {
                    alert("Could not reset anonymization: " + data.status);
                } else {
                    alert("Could not reset anonymization.");
                }
            }
        }).fail(function() {
            $('#overlay').hide();
            alert("Could not reset anonymization.");
        });
    });
});
